/********************************************************************************/
/*****                                                                      *****/
/*****  TITLE:          Politics on Display, Ch. 1 Supporting Materials     *****/
/*****  AUTHORS:        Makse, Minkoff, Sokhey                              *****/
/*****  DESC:           Pull out and code variables from 2000 ANES          *****/
/*****                  (American National Election Study); estimate models *****/
/*****                                                                      *****/                
/********************************************************************************/

/***********Comment: This do-file starts with a "raw" version of the 2000 ANES ("anes2000TS.dta", and    */
*creates variables for analysis (network items, as well as other covariates), before                     */
*estimating models predicting displaying a yard sign (as well as several other                           */
*participatory acts). The model estimates  were used to create Figure 1.2 in Chapter 1,                  */
*and in our discussion of how sign displaying is a "social act."  Network                                */
*disagreement -- generally the main attribute in the literature on social influence --                   */
*only emerges as a significant predictor of sign displaying (it does not emerge for                      */
*other particiatory acts).                                                                               */                        

foreach v of varlist _all {
      capture rename `v' `=lower("`v'")'
   }


rename v000001 caseid
label var caseid "Case id"

rename v000001a postid
label var postid "Post-election case id"


************************
*DVs********************
************************ 

*participation 

rename v001225 pstpers
label var pstpers "R tried to persuade others how to vote, post election"
recode pstpers 5=0
label val pstpers yesno

rename v001226 pstsign
label var pstsign "R displayed bumper sticker, button, or sign, post election"
recode pstsign 5=0
label val pstsign yesno

rename v001227 pstrally
label var pstrally "R attended meeting or rally, post election"
recode pstrally 5=0
label val pstrally yesno

rename v001228 pstcwork
label var pstcwork "R did campaign work, post election"
recode pstcwork 5=0
label val pstcwork yesno

rename v001229 pstdonate
label var pstdonate "R donated money to campaign, post election"
recode pstdonate 5=0
label val pstdonate yesno

*create index of political acts 
generate partindex=pstpers+pstsign+pstrally+pstcwork+pstdonate

*check reliability of index 
alpha pstpers pstsign pstrally pstcwork pstdonate

*(it's not great) 


***timing of decision:

rename v001251 pstwhen
label var pstwhen "Timing of R's vote decision, post election"
recode pstwhen 1=0 2/4=1 5/6=2 7=3 8=4 9=5 10=6 11=1 97=.
label def when 0 "All along" 1 "Primaries or convention" 2 "Early in campaign" 3 "Month before" 4 "Two weeks before" 5 "Last few days" 6 "Election Day"
label val pstwhen when

***turnout 

rename v001248 psttrn
label var psttrn "R voted in presidential election, post election"
recode psttrn 5=0
label val psttrn yesno

rename v001249 pstvote
label var pstvote "R's presidential vote choice, post election"




******************************************************************
******************************************************************
**************political discussion items**************************
******************************************************************

rename v001699 d1
label var d1 "R names first discussant"
recode d1 5=0
label val d1 yesno

rename v001700 d2
label var d2 "R names second discussant"
recode d2 5=0
label val d2 yesno

rename v001701 d3
label var d3 "R names third discussant"
recode d3 5=0
label val d3 yesno

rename v001702 d4
label var d4 "R names fourth discussant"
recode d4 5=0
label val d4 yesno

rename v001708 dptalk1
label var dptalk1 "Frequency R talks politics with D1"
recode dptalk1 7=0 5=1 3=2 1=3
label def ptalk 0 "never" 1 "rarely" 2 "sometimes" 3 "often"
label val dptalk1 ptalk

rename v001709 dknow1
label var dknow1 "How much D1 knows about politics"
recode dknow1 5=0 3=1 1=2
label def dknow 0 "not much" 1 "average amt" 2 "great deal"
label val dknow1 dknow

rename v001710 dvote1
label var dvote1 "Who did D1 vote for in pres election?"

gen ddisag1=.
label var ddisag1 "R and D1 voted for dif candidates"
replace ddisag1=1 if d1==1
replace ddisag1=0 if d1==1 & pstvote==1 & dvote1==1
replace ddisag1=0 if d1==1 & pstvote==3 & dvote1==3
replace ddisag1=0 if d1==1 & psttrn==0 & dvote1==7
replace ddisag1=0 if d1==1 & psttrn==1 & dvote1==8

        /*****  NOTE -- If R notes that D voted for some other candidate, that is coded as disagreement b/c we cannot match them *****/

rename v001716 dptalk2
label var dptalk2 "Frequency R talks politics with D2"
recode dptalk2 7=0 5=1 3=2 1=3
label val dptalk2 ptalk

rename v001717 dknow2
label var dknow2 "How much D2 knows about politics"
recode dknow2 5=0 3=1 1=2
label val dknow2 dknow

rename v001718 dvote2
label var dvote2 "Who did D2 vote for in pres election?"

gen ddisag2=.
label var ddisag2 "R and D2 voted for dif candidates"
replace ddisag2=1 if d2==1
replace ddisag2=0 if d2==1 & pstvote==1 & dvote2==1
replace ddisag2=0 if d2==1 & pstvote==3 & dvote2==3
replace ddisag2=0 if d2==1 & psttrn==0 & dvote2==7
replace ddisag2=0 if d2==1 & psttrn==1 & dvote2==8

rename v001724 dptalk3
label var dptalk3 "Frequency R talks politics with D3"
recode dptalk3 7=0 5=1 3=2 1=3
label val dptalk3 ptalk

rename v001725 dknow3
label var dknow3 "How much D3 knows about politics"
recode dknow3 5=0 3=1 1=2
label val dknow3 dknow

rename v001726 dvote3
label var dvote3 "Who did D3 vote for in pres election?"

gen ddisag3=.
label var ddisag3 "R and D3 voted for dif candidates"
replace ddisag3=1 if d3==1
replace ddisag3=0 if d3==1 & pstvote==1 & dvote3==1
replace ddisag3=0 if d3==1 & pstvote==3 & dvote3==3
replace ddisag3=0 if d3==1 & psttrn==0 & dvote3==7
replace ddisag3=0 if d3==1 & psttrn==1 & dvote3==8

rename v001732 dptalk4
label var dptalk4 "Frequency R talks politics with D4"
recode dptalk4 7=0 5=1 3=2 1=3
label val dptalk4 ptalk

rename v001733 dknow4
label var dknow4 "How much D4 knows about politics"
recode dknow4 5=0 3=1 1=2
label val dknow4 dknow

rename v001734 dvote4
label var dvote4 "Who did D4 vote for in pres election?"

gen ddisag4=.
label var ddisag4 "R and D2 voted for dif candidates"
replace ddisag4=1 if d4==1
replace ddisag4=0 if d4==1 & pstvote==1 & dvote4==1
replace ddisag4=0 if d4==1 & pstvote==3 & dvote4==3
replace ddisag4=0 if d4==1 & psttrn==0 & dvote4==7
replace ddisag4=0 if d4==1 & psttrn==1 & dvote4==8

*****************************************************
gen netsize=0
replace netsize=. if d1==.
replace netsize=1 if d1==1
replace netsize=2 if d2==1
replace netsize=3 if d3==1
replace netsize=4 if d4==1
label var netsize "Size of R's network"

gen anetknow=.
label var anetknow "Average level of political knowledge in R's network"
replace anetknow=0 if netsize==0
replace anetknow=dknow1 if netsize==1
replace anetknow=(dknow1+dknow2)/2 if netsize==2
replace anetknow=(dknow1+dknow2+dknow3)/3 if netsize==3
replace anetknow=(dknow1+dknow2+dknow3+dknow4)/4 if netsize==4

gen anetptalk=.
label var anetptalk "Average level of political discussion in R's network"
replace anetptalk=0 if netsize==0
replace anetptalk=dptalk1 if netsize==1
replace anetptalk=(dptalk1+dptalk2)/2 if netsize==2
replace anetptalk=(dptalk1+dptalk2+dptalk3)/3 if netsize==3
replace anetptalk=(dptalk1+dptalk2+dptalk3+dknow4)/4 if netsize==4

gen anetdisag=.
label var anetdisag "Average level of disagreement in R's network"
replace anetdisag=0 if netsize==0
replace anetdisag=ddisag1 if netsize==1
replace anetdisag=(ddisag1+ddisag2)/2 if netsize==2
replace anetdisag=(ddisag1+ddisag2+ddisag3)/3 if netsize==3
replace anetdisag=(ddisag1+ddisag2+ddisag3+ddisag4)/4 if netsize==4







*****************************************************
*****************************************************
*************control variables***********************
*****************************************************

rename v001356 pstknow1
label var pstknow1 "Party controlled house b/f election correct, post election"
recode pstknow1 1=0 5=1
replace pstknow1=0 if pstknow1==.
label val pstknow1 yesno

rename v001357 pstknow2
label var pstknow2 "Party controlled house b/f election correct, post election"
recode pstknow2 1=0 5=1
replace pstknow2=0 if pstknow2==.
label val pstknow2 yesno

rename v001447 pstknow3
label var pstknow3 "Knows Lott is Sen Maj leader, post election"
recode pstknow3 5=0
replace pstknow3=0 if pstknow3==.
label val pstknow3 yesno

rename v001450 pstknow4
label var pstknow4 "Knows Rehnquist is CJ of SC, post election"
recode pstknow4 5=0
replace pstknow4=0 if pstknow4==.
label val pstknow4 yesno

rename v001453 pstknow5
label var pstknow5 "Knows Blair is PM of GB, post election"
recode pstknow5 5=0
replace pstknow5=0 if pstknow5==.
label val pstknow5 yesno

rename v001456 pstknow6
label var pstknow6 "Knows Reno is AG, post election"
recode pstknow6 5=0
replace pstknow6=0 if pstknow6==.
label val pstknow6 yesno

rename v001458 pstknow7
label var pstknow7 "Knows Bush is from TX, post election"
recode pstknow7 1/2=0 3=1 4/7=0
replace pstknow7=0 if pstknow7==.
label val pstknow7 yesno

rename v001462 pstknow8
label var pstknow8 "Knows Gore is from TN, post election"
recode pstknow8 1=0 2=1 3/7=0
replace pstknow8=0 if pstknow8==.
label val pstknow8 yesno

rename v001466 pstknow9
label var pstknow9 "Knows Cheney is from WY, post election"
recode pstknow9 1/3=0 4=1 7=0
replace pstknow9=0 if pstknow9==.
label val pstknow9 yesno

rename v001470 pstknow10
label var pstknow10 "Knows Liberman is from CT, post election"
recode pstknow10 2/7=0
replace pstknow10=0 if pstknow10==.
label val pstknow10 yesno

**use these to create a political knowledge measure 

gen know=pstknow1+pstknow2+pstknow3+pstknow4+pstknow5+pstknow6+pstknow7+pstknow8+pstknow9+pstknow10
label var know "R's political knowledge"


rename v000523 pid7
label var pid7 "Seven point party identification scale, pre election"
recode pid7 0=-3 1=-2 2=-1 3=0 4=1 5=2 6=3 7=.
label def pid7 -3 "str dem" -2 "weak dem" -1 "lean dem" 0 "ind" 1 "lean rep" 2 "weak rep" 3 "str rep"
label val pid7 pid7

recode pid7 (0=0) (-1=1) (-2=2) (-3=3) (else=0), gen(strpiddem)

recode pid7 (0=0) (1=1) (2=2) (3=3) (else=0), gen(strpidrep)

recode pid7 (-3=3) (-2=2) (-1=1) (0=0) (1=1) (2=2) (3=3), gen(strpid) 


rename v001368 pstideol7
label var pstideol7 "Ideology on 7-point scale, post election"
recode pstideol7 1=-3 2=-2 3=-1 4=0 5=1 6=2 7=3
label val pstideol ideol7

gen pstideol3=pstideol7
label var pstideol3 "Ideology on 3-point scale, post election"
recode pstideol3 -3/-2=-1 -1/1=0 2/3=1
label val pstideol3 ideol3


rename v000908 age
label var age "R's age in years"

rename v000909 marstat
label var marstat "R's marital status"

rename v000913 education
label var education "R's level of education"

rename v000997 income
label var income "R's household income"
rename v001006a ethnic1
label var ethnic1 "R's first named ethnicity"

rename v001006b ethnic2
label var ethnic1 "R's second named ethnicity"

rename v001006c ethnic3
label var ethnic3 "R's third named ethnicity"

gen white=.
replace white=1 if ethnic1==50
replace white=0 if ethnic1<50
replace white=0 if ethnic1>50
label var white "R is non-hispanic white"
label val white yesno

rename v001029 female
label var female "R is a female"
recode female 1=0 2=1
label val female yesno

rename v001201 pstint
label var pstint "Interest in campaign, post election"
recode pstint 5=0 3=1 1=2
label values pstint three

**************************************************************
**************************************************************
*predict displaying a yard sign (estimates for Figure 1.2, Chapter 1):

logit pstsign age pstint education strpid income female white anetknow anetdisag anetptalk netsize if netsize>0

*predict other participatory acts (discussed in Chapter 1 -- network disagreement only matters for sign displaying)
logit pstrally age pstint education strpid income female white anetknow anetdisag anetptalk netsize if netsize>0

logit pstcwork age pstint education strpid income female white anetknow anetdisag anetptalk netsize if netsize>0

logit pstdonate age pstint education strpid income female white anetknow anetdisag anetptalk netsize if netsize>0




